===================
heat-keystone-setup
===================

.. program:: heat-keystone-setup


SYNOPSIS
========

``heat-keystone-setup``


DESCRIPTION
===========
Warning: This script is deprecated, please use other tool to setup keystone
for heat.

The ``heat-keystone-setup`` tool configures keystone for use with heat. This
script requires admin keystone credentials to be available in the shell
environment and write access to ``/etc/keystone``.

Distributions may provide other tools to setup keystone for use with Heat, so
check the distro documentation first.

EXAMPLES
========

  heat-keystone-setup

BUGS
====

Heat bugs are managed through StoryBoard
`OpenStack Heat Stories <https://storyboard.openstack.org/#!/project/989>`__
